@@ -16,8 +16,7 @@ runner = TestRunner(suite=suite,
                     title="前程贷接口自动化执行结果",
                     templates=2)
 
-runner.run()
-
+# runner.run()
 # runner.send_email(host="smtp.qq.com",
 #                   port=465,
 #                   user="musen_nmb@qq.com",
