@@ -25,7 +25,7 @@ class TestClass(unittest.TestCase):
 
     @json_data("cases.json")
     def test_case01(self, data):
-        pass
+        print(data)
 
     # @yaml_data("cases.yaml")
     # def test_case02(self, data):
