@@ -14,5 +14,5 @@ unittestreport基于unittest扩展了5个功能：
 """
 
 from unittestreport.core.testRunner import TestRunner
-from .core.dataDriver import ddt, data
+from .core.dataDriver import ddt, list_data, json_data, yaml_data
 from .core.reRun import rerun
